@@ -72,11 +72,16 @@ initialize=function(id=NA_character_, cache.id=NA_character_, bdb, ...) {
     private$cache.id <- if (is.null(cache.id)) NA_character_ else cache.id
     private$entries <- list()
 
-    # Register with request scheduler
-    if (self$isRemotedb()) {
-        logDebug("Register connector %s with the request scheduler", id)
-        private$bdb$getRequestScheduler()$registerConnector(self)
-    }
+    # Define rules in request scheduler
+    if (self$isRemotedb())
+
+        # Loop on all connector URLs
+        for (url in self$getPropertyValue('urls')) {
+            host <- sched::URL$new(url)$getDomain()
+            n <- self$getPropertyValue('scheduler.n')
+            lap <- self$getPropertyValue('scheduler.t')
+            private$bdb$getRequestScheduler()$setRule(host, n=n, lap=lap)
+        }
 
     return(invisible(NULL))
 },
@@ -152,8 +157,9 @@ getEntry=function(id, drop=TRUE, nulls=TRUE) {
 #' entry IDs.
 getCacheFile=function(entry.id) {
 
-    c <- private$bdb$getPersistentCache()
-    fp <- c$getFilePath(self$getCacheId(), entry.id, self$getEntryFileExt())
+    cch <- private$bdb$getPersistentCache()
+    fp <- cch$getPaths(sub_folder=self$getCacheId(), paths=entry.id,
+                       suffix=paste0('.', self$getEntryFileExt()))
 
     return(fp)
 },
@@ -182,11 +188,11 @@ getEntryContent=function(id) {
             self$download()
 
         # Initialize content
-        if (cch$isReadable(self) && ! is.null(self$getCacheId())) {
+        if (cch$isReadable() && ! is.null(self$getCacheId())) {
             # Load content from cache
-            content <- cch$loadFileContent(self$getCacheId(),
-                name=id, ext=self$getEntryFileExt())
-            missing.ids <- id[vapply(content, is.null, FUN.VALUE=TRUE)]
+            content <- cch$loadContents(sub_folder=self$getCacheId(),
+                paths=id, suffix=paste0('.', self$getEntryFileExt()))
+            missing.ids <- id[vapply(content, is.na, FUN.VALUE=TRUE)]
         }
         else {
             content <- lapply(id, as.null)
@@ -203,7 +209,7 @@ getEntryContent=function(id) {
         # Debug
         if (any(is.na(id)))
             logDebug("%d %s entry ids are NA.", sum(is.na(id)), nm)
-        if (cch$isReadable(self)) {
+        if (cch$isReadable()) {
             nld <- sum( ! is.na(id)) - length(missing.ids)
             logDebug("%d %s entry content(s) loaded from cache.", nld, nm)
             if (n.duplicates > 0)
@@ -236,16 +242,16 @@ getEntryContent=function(id) {
 
                 # Save to cache
                 if ( ! is.null(ec)
-                    && ! is.null(self$getCacheId()) && cch$isWritable(self))
-                    cch$saveContentToFile(ec,
-                        cache.id=self$getCacheId(), name=ch.missing.ids,
-                        ext=self$getEntryFileExt())
+                    && ! is.null(self$getCacheId()) && cch$isWritable())
+                    cch$saveContents(ec,
+                        sub_folder=self$getCacheId(), dst=ch.missing.ids,
+                        suffix=paste0('.', self$getEntryFileExt()))
 
                 # Append
                 missing.contents <- c(missing.contents, ec)
 
                 # Debug
-                if (cch$isReadable(self)) {
+                if (cch$isReadable()) {
                     n <- length(missing.ids) - length(missing.contents)
                     logDebug("Now %d id(s) left to be retrieved...", n)
                 }
@@ -471,8 +477,9 @@ addNewEntry=function(entry) {
 
         # Remove entry from non-volatile cache
         cch <- private$bdb$getPersistentCache()
-        if (cch$isWritable(self))
-            cch$deleteFile(self$getCacheId(), name=id, ext=self$getEntryFileExt())
+        if (cch$isWritable())
+            cch$delPaths(sub_folder=self$getCacheId(), paths=id,
+                suffix=paste0('.', self$getEntryFileExt()))
 
         # Flag entry as new
         entry$.__enclos_env__$private$setAsNew(TRUE)
@@ -707,7 +714,7 @@ isDownloaded=function() {
 
     private$checkIsDownloadable()
     cch <- private$bdb$getPersistentCache()
-    dwnlded  <- cch$markerExists(self$getCacheId(), name='downloaded')
+    dwnlded  <- cch$tagExists(sub_folder=self$getCacheId(), name='downloaded')
 
     s <- (if (dwnlded) 'already' else 'not yet')
     logDebug0('Database ', self$getId(), ' has ', s, ' been downloaded.')
@@ -730,8 +737,9 @@ getDownloadPath=function() {
 
     private$checkIsDownloadable()
     cch <- private$bdb$getPersistentCache()
-    ext <- self$getPropertyValue('dwnld.ext')
-    path <- cch$getFilePath(self$getCacheId(), name='download', ext=ext)
+    ext <- paste0('.', self$getPropertyValue('dwnld.ext'))
+    path <- cch$getPaths(sub_folder=self$getCacheId(), paths='download',
+        suffix=ext)
 
     logDebug0('Download path of ', self$getId(), ' is "', path, '".')
 
@@ -747,16 +755,16 @@ setDownloadedFile=function(src, action=c('copy', 'move')) {
 
     private$checkIsDownloadable()
     cch <- private$bdb$getPersistentCache()
-    ext <- self$getPropertyValue('dwnld.ext')
+    ext <- paste0('.', self$getPropertyValue('dwnld.ext'))
     name <- 'download'
     cache.id <- self$getCacheId()
 
     # Remove if already exists
-    if (cch$fileExists(cache.id=cache.id, name=name, ext=ext))
-        cch$deleteFile(cache.id=cache.id, name=name, ext=ext)
+    if (cch$pathsExist(sub_folder=cache.id, paths=name, suffix=ext))
+        cch$delPaths(sub_folder=cache.id, paths=name, suffix=ext)
 
     # Import
-    cch$addFilesToCache(src, cache.id=cache.id, name=name, ext=ext,
+    cch$importFiles(src=src, sub_folder=cache.id, dst=name, suffix=ext,
         action=action)
 
     return(invisible(NULL))
@@ -771,7 +779,7 @@ isExtracted=function() {
 
     private$checkIsDownloadable()
     cch <- private$bdb$getPersistentCache()
-    return(cch$markerExists(self$getCacheId(), name='extracted'))
+    return(cch$tagExists(sub_folder=self$getCacheId(), name='extracted'))
 },
 
 #' @description
@@ -784,7 +792,7 @@ download=function() {
 
     # Download
     cfg <- private$bdb$getConfig()
-    if (cch$isWritable(self) && ! self$isDownloaded()
+    if (cch$isWritable() && ! self$isDownloaded()
         && (cfg$isEnabled('allow.huge.downloads') || self$requiresDownload())
         && ! cfg$isEnabled('offline')) {
 
@@ -796,7 +804,7 @@ download=function() {
         logDebug0('Downloading of ', self$getId(), ' completed.')
 
         # Set marker
-        cch$setMarker(self$getCacheId(), name='downloaded')
+        cch$writeTag(sub_folder=self$getCacheId(), name='downloaded')
     }
 
     # Extract
@@ -807,7 +815,7 @@ download=function() {
         private$doExtractDownload()
 
         # Set marker
-        cch$setMarker(self$getCacheId(), name='extracted')
+        cch$writeTag(sub_folder=self$getCacheId(), name='extracted')
     }
 
     return(invisible(NULL))
@@ -1064,9 +1072,9 @@ deleteAllEntriesFromPersistentCache=function(deleteVolatile=TRUE) {
 
     if (deleteVolatile)
         self$deleteAllEntriesFromVolatileCache()
-    fileExt <- self$getPropertyValue('entry.content.type')
-    private$bdb$getPersistentCache()$deleteFiles(self$getCacheId(),
-        ext=fileExt)
+    fileExt <- paste0('.', self$getPropertyValue('entry.content.type'))
+    private$bdb$getPersistentCache()$delPaths(sub_folder=self$getCacheId(),
+        suffix=fileExt)
     
     return(invisible(NULL))
 },
@@ -1081,7 +1089,7 @@ deleteWholePersistentCache=function(deleteVolatile=TRUE) {
 
     if (deleteVolatile)
         self$deleteAllEntriesFromVolatileCache()
-    private$bdb$getPersistentCache()$deleteAllFiles(self$getCacheId())
+    private$bdb$getPersistentCache()$delFolder(self$getCacheId())
 
     return(invisible(NULL))
 },
@@ -1156,17 +1164,12 @@ makesRefToEntry=function(id, db, oid, any=FALSE, recurse=FALSE) {
 },
 
 #' @description
-#' Makes a BiodbRequest instance using the passed parameters, and set
-#'     ifself as the associated connector.
-#' @param ... Those parameters are passed to the initializer of BiodbRequest.
-#' @return The BiodbRequest instance.
+#' Makes a sched::Request instance using the passed parameters.
+#'
+#' @param ... Those parameters are passed to the initializer of sched::Request.
+#' @return The sched::Request instance.
 makeRequest=function(...) {
-
-    req <- BiodbRequest$new(...)
-
-    req$setConn(self)
-
-    return(req)
+    return(sched::Request$new(...))
 },
 
 #' @description
@@ -1184,7 +1187,7 @@ getEntryImageUrl=function(entry.id) {
 #' @description
 #' Gets the URL to the page of the entry on the database web site.
 #' @param entry.id A character vector with the IDs of entries to retrieve.
-#' @return A list of BiodbUrl objects, the same length as `entry.id`.
+#' @return A list of sched::URL objects, the same length as `entry.id`.
 getEntryPageUrl=function(entry.id) {
 
     private$checkIsRemote()
@@ -1980,9 +1983,9 @@ doGetEntryContentOneByOne=function(entry.id) {
 
     # If requests is a vector of characters, then the method is using the old
     # scheme.
-    # We now convert the requests to the new scheme, using class BiodbRequest.
+    # We now convert the requests to the new scheme, using class sched::Request.
     if (is.character(requests)) {
-        fct <- function(x) self$makeRequest(method='get', url=BiodbUrl$new(x),
+        fct <- function(x) self$makeRequest(method='get', url=sched::URL$new(x),
             encoding=encoding)
         requests <- lapply(requests, fct)
     }
@@ -2378,13 +2381,4 @@ computeChromColRtRange=function(entry) {
     return( ! is.null(self$getEntry(id)))
 }
 
-,terminate=function() {
-
-    # Unregister from the request scheduler
-    if (self$isRemotedb()) {
-        logDebug("Unregister connector %s from the request scheduler",
-            self$getId())
-        private$bdb$getRequestScheduler()$unregisterConnector(self)
-    }
-}
 ))
