@@ -246,7 +246,9 @@ test.entry.page.url.download <- function(conn, opt) {
     # Try downloading
     if ( ! is.na(url)) {
         biodb::logDebug('Trying to download "%s".', url)
-        content <- getUrlContent(url)
+        request <- sched::Request$new(URL$new(url))
+        result <- sched::get_url_request_result(request)
+        content <- result$getContent()
         testthat::expect_true( ! is.na(content))
         testthat::expect_true(nchar(content) > 0)
         testthat::expect_length(grep('<title>.*Not Found</title>', content), 0)
@@ -264,8 +266,9 @@ test.entry.image.url.download <- function(conn, opt) {
 
     # Try downloading
     if ( ! is.na(url)) {
-        content <- getUrlContent(url, binary=TRUE)
-        testthat::expect_is(content, 'raw')
+        request <- sched::Request$new(URL$new(url))
+        result <- sched::get_url_request_result(request, binary=TRUE)
+        testthat::expect_is(result$getContent(), 'raw')
     }
 }
 
@@ -530,7 +533,7 @@ test.searchByName <- function(conn, opt) {
             '".')
         testthat::expect_true( ! is.null(ids), msg)
         testthat::expect_true(length(ids) > 0, msg)
-        testthat::expect_true(id %in% ids, msg)
+        testthat::expect_true(!!id %in% !!ids, msg)
     }
     else {
         testthat::expect_warning(conn$searchByName(name='foo'))
@@ -1529,8 +1532,8 @@ runGenericLongTests <- function(conn, opt) {
 #' conn <- biodb$getFactory()$createConn('mass.csv.file', lcmsdb)
 #'
 #' # Run generic tests
-#' \donttest{
-#' biodb::runGenericTests(conn)
+#' \dontrun{
+#' biodb::runGenericTests(conn, 'mypkg')
 #' }
 #'
 #' # Terminate the instance
