@@ -7,11 +7,19 @@
 #' ```
 #'
 #' @seealso \link{BiodbMain}, \link{BiodbConfig}, \link{BiodbFactory},
-#' \link{BiodbPersistentCache}, \link{BiodbDbsInfo}, \link{BiodbEntryFields}.
+#' \link{BiodbDbsInfo}, \link{BiodbEntryFields}.
 #'
 #' @import withr
 #' @import Rcpp
+#' @import sched
 #' @importFrom Rcpp evalCpp
 #' @useDynLib biodb, .registration=TRUE
 "_PACKAGE"
+
+# For retro-compatibility
+BiodbUrl <- sched::URL
+BiodbRequest <- sched::Request
+BiodbRequestScheduler <- sched::Scheduler
+BiodbRequestSchedulerRule <- sched::Rule
+
 NULL
